@extends('layouts.master')

@section('css')
    <!-- Table css -->
    <link href="{{ URL::asset('plugins/RWD-Table-Patterns/dist/css/rwd-table.min.css') }}" rel="stylesheet" type="text/css" media="screen">
@endsection

@section('breadcrumb')
    <div class="col-sm-6">
        <h4 class="page-title text-left">Attendance</h4>
        <ol class="breadcrumb">
            <li class="breadcrumb-item"><a href="javascript:void(0);">Home</a></li>
            <li class="breadcrumb-item"><a href="javascript:void(0);">Attendance</a></li>
        </ol>
    </div>
@endsection

@section('content')
@include('includes.flash')

    <div class="row">
        <div class="col-12">
            <div class="card">
                <div class="card-body">
                    <div class="table-rep-plugin">
                        <div class="table-responsive mb-0" data-pattern="priority-columns">
                            <table id="datatable-buttons" class="table table-striped table-bordered dt-responsive nowrap" style="border-collapse: collapse; border-spacing: 0; width: 100%;">
                                        
                                <thead>
                                    <tr>
                                        <th data-priority="1">Tanggal</th>
                                        <th data-priority="2">Nama</th>
                                        <th data-priority="4">Status</th>
                                        <th data-priority="5">Clock Type</th>
                                        <th data-priority="6">Keterangan</th>
                                        <th data-priority="7">Latitude</th>
                                        <th data-priority="8">Longitude</th>
                                        <th data-priority="9">Foto</th>
                                        <th data-priority="10">Actions</th>
                                    </tr>
                                </thead>
                                <tbody>
                                    @foreach ($presensis as $presensi)
                                        <tr>
                                            <td>{{ $presensi->created_at->format('Y-m-d H:i:s') }}</td>
                                            <td>{{ $presensi->user->name ?? 'N/A' }}</td>
                                           
                                            <td>
                                                @if ($presensi->status == 'Hadir')
                                                    <span class="badge badge-primary">{{ $presensi->status }}</span>
                                                @elseif ($presensi->status == 'Sakit')
                                                    <span class="badge badge-warning">{{ $presensi->status }}</span>
                                                @elseif ($presensi->status == 'Izin')
                                                    <span class="badge badge-info">{{ $presensi->status }}</span>
                                                @else
                                                    <span class="badge badge-danger">{{ $presensi->status }}</span>
                                                @endif
                                            </td>
                                            <td>
                                                @if ($presensi->clock_type == 'in')
                                                    <span class="badge badge-success">Clock In</span>
                                                @else
                                                    <span class="badge badge-danger">Clock Out</span>
                                                @endif
                                            </td>
                                            <td>{{ $presensi->keterangan }}</td>
                                            <td>{{ $presensi->latitude }}</td>
                                            <td>{{ $presensi->longitude }}</td>
                                            <td>
                                                @if ($presensi->foto)
                                                    <a href="{{ asset('storage/' . $presensi->foto) }}" target="_blank">
                                                        <img src="{{ asset('storage/' . $presensi->foto) }}" alt="Foto Presensi" class="img-thumbnail" style="max-width: 50px;">
                                                    </a>
                                                @else
                                                    No Image
                                                @endif
                                            </td>
                                            <td>
                                                <form action="{{ route('attendance.destroy', $presensi->id) }}" method="POST" style="display: inline-block;" id="delete-form-{{ $presensi->id }}">
                                                    @csrf
                                                    @method('DELETE')
                                                    <button type="button" class="btn btn-danger btn-sm" onclick="confirmDelete({{ $presensi->id }})">
                                                        <i class="fas fa-trash"></i> Delete
                                                    </button>
                                                </form>
                                            </td>
                                        </tr>
                                    @endforeach
                                </tbody>
                            </table>
                        </div>
                    </div>
                </div>
            </div>
        </div> <!-- end col -->
    </div> <!-- end row -->

@endsection

@section('script')
    <!-- Responsive-table-->
    <script src="{{ URL::asset('plugins/RWD-Table-Patterns/dist/js/rwd-table.min.js') }}"></script>
    <!-- Sweet-Alert  -->
    <script src="https://cdn.jsdelivr.net/npm/sweetalert2@11"></script>
    
    <script>
        $(function() {
            $('.table-responsive').responsiveTable({
                addDisplayAllBtn: 'btn btn-secondary'
            });
        });

        function confirmDelete(id) {
            Swal.fire({
                title: 'Apakah anda yakin?',
                text: "Data yang dihapus tidak dapat dikembalikan!",
                icon: 'warning',
                showCancelButton: true,
                confirmButtonColor: '#3085d6',
                cancelButtonColor: '#d33',
                confirmButtonText: 'Ya, hapus!',
                cancelButtonText: 'Batal'
            }).then((result) => {
                if (result.isConfirmed) {
                    document.getElementById('delete-form-' + id).submit();
                }
            });
        }
    </script>
@endsection
